@@ -241,6 +241,16 @@ test_that('lm execution', {
     regexp = NA
   )
 
+  expect_error(
+    res <- fit_xy(
+      hpc_basic,
+      x = hpc[, num_pred],
+      y = hpc$class,
+      control = ctrl
+    ),
+    regexp = "For a regression model"
+  )
+
   expect_error(
     res <- fit(
       hpc_basic,
@@ -250,13 +260,15 @@ test_that('lm execution', {
     )
   )
 
-  lm_form_catch <- fit(
-    hpc_basic,
-    hpc_bad_form,
-    data = hpc,
-    control = caught_ctrl
+  expect_error(
+    lm_form_catch <- fit(
+      hpc_basic,
+      hpc_bad_form,
+      data = hpc,
+      control = caught_ctrl
+    ),
+    regexp = "For a regression model"
   )
-  expect_true(inherits(lm_form_catch$fit, "try-error"))
 
   ## multivariate y
 
@@ -371,3 +383,10 @@ test_that('default engine', {
   expect_true(inherits(fit$fit, "lm"))
 })
 
+test_that('show engine', {
+  res <- show_engines("linear_reg")
+  expt <- get_from_env("linear_reg")
+  expect_equal(res, expt)
+  expect_error(show_engines("linear_re"), "No results found for model function")
+})
+
