@@ -6,7 +6,8 @@ library(tibble)
 
 # ------------------------------------------------------------------------------
 
-source("helper-objects.R")
+source(test_path("helper-objects.R"))
+
 
 basic_form <- Surv(time, status) ~ age
 complete_form <- Surv(time) ~ age
